@@ -1,3 +1,5 @@
+#-*- coding: utf-8 -*
+
 CSS_1 = '''
 /* Comment 1 */
 div#main { 
@@ -285,6 +287,26 @@ expect_HTML_8=u'''
 '''
 
 
+#----------------------------------------------------------------------------
+
+HTML_9=u'''
+<html>
+  <style>
+  * { color:#000000; 
+      background-color:#ffcc99 ;
+    }
+  </style>
+  <body>
+    <div style="color:#CCCCCC; background-color: #ee99cc">Pay with \xa3</div>
+  </body>
+</html>
+'''
+
+expect_HTML_9=u'''
+<html><style> *{color:#000;background-color:#fc9}</style><body><div style="color:#CCCCCC; background-color: #ee99cc">Pay with \xa3</div></body></html>
+'''
+
+
 #----------------------------------------------------------------------------
 
 JS_1='''
